<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="93"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="94"/>
        <location filename="../fileops.cpp" line="134"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Doelmap bestaat niet</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="137"/>
        <source>Move Files</source>
        <translation>Bestanden verplaatsen</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="138"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Weet je zeker dat je %n bestand wilt verplaatsen?</numerusform>
            <numerusform>Weet je zeker dat je %n bestanden wilt verplaatsen?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <source>Copying</source>
        <translation>Bezig met kopiëren</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="155"/>
        <location filename="../fileops.cpp" line="249"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="200"/>
        <source>Copying file %1/%2</source>
        <translation>Kopiëer bestand: %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="248"/>
        <source>Moving</source>
        <translation>Bezig met verplaatsen</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="284"/>
        <source>Moving file %1/%2</source>
        <translation>Bezig met verplaatsen: %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="109"/>
        <source>Remove Files</source>
        <translation>Bestanden verwijderen</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="110"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Weet u zeker dat u dit bestand wilt verwijderen?</numerusform>
            <numerusform>Weet u zeker dat u deze %n bestanden wilt verwijderen?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Bestands Beheer Module</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Over de Bestands Beheer Module</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Bestands Beheer Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Sneltoets Aanpassen</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Druk de toetscombinatie die u wilt toewijzen</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Leeghalen</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Instellingen van Bestandsbeheer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Ingeschakeld</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Actie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Menutekst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Sneltoets</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Doel:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Bestandsnaam patroon:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Kopiëer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Hernoem</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>Verplaatsen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Nieuwe actie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>Kies een map</translation>
    </message>
</context>
</TS>
